# TODO
# - -rt subpackage? -lang subpackage?
# - <meta>-xxx keybindings (alt+something) incompatibility
#   https://github.com/neovim/neovim/issues/5576
#
# Conditional build:
%bcond_without	lua		# LUA

Summary:	Vim-fork focused on extensibility and agility
Name:		neovim
Version:	0.2.0
Release:	1
License:	Apache v2.0
Group:		Applications/Editors/Vim
Source0:	https://github.com/neovim/neovim/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	9af7f61f9f0b1a2891147a479d185aa2
URL:		https://neovim.io/
Source1:	%{name}.desktop
Source2:	%{name}.svg
BuildRequires:	cmake >= 2.8.7
BuildRequires:	gcc >= 6:4.4
BuildRequires:	gettext-devel
BuildRequires:	jemalloc-devel
BuildRequires:	libstdc++-devel
BuildRequires:	libtermkey-devel
BuildRequires:	libuv-devel
BuildRequires:	libvterm-devel
BuildRequires:	msgpack-devel >= 1.1.0
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.596
BuildRequires:	unibilium-devel
%if %{with lua}
BuildRequires:	lua-bitop >= 1.0.2
BuildRequires:	lua-lpeg
BuildRequires:	lua-mpack >= 1.0.2
BuildRequires:	lua51
%endif
Requires:	desktop-file-utils
Requires:	gtk-update-icon-cache
Requires:	hicolor-icon-theme
Suggests:	python-neovim
Suggests:	python3-neovim
Suggests:	ruby-neovim
Suggests:	xsel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# gcc 4.0 and better turn on _FORTIFY_SOURCE=2 automatically. This currently
# does not work with Neovim due to some uses of dynamically-sized structures.
# See https://github.com/neovim/neovim/issues/223 for details.
%define		filterout_c	-Wp,-D_FORTIFY_SOURCE=2

%description
Neovim is a refactor - and sometimes redactor - in the tradition of
Vim, which itself derives from Stevie. It is not a rewrite, but a
continuation and extension of Vim. Many rewrites, clones, emulators
and imitators exist; some are very clever, but none are Vim. Neovim
strives to be a superset of Vim, notwithstanding some intentionally
removed misfeatures; excepting those few and carefully-considered
excisions, Neovim is Vim. It is built for users who want the good
parts of Vim, without compromise, and more.

%prep
%setup -q

%build
install -d .deps build
cd .deps
%cmake \
	-DUSE_BUNDLED=OFF \
	-DUSE_BUNDLED_JEMALLOC=OFF \
	-DUSE_BUNDLED_UNIBILIUM=OFF \
	-DUSE_BUNDLED_LIBTERMKEY=OFF \
	-DUSE_BUNDLED_LIBVTERM=OFF \
	-DUSE_BUNDLED_LIBUV=OFF \
	-DUSE_BUNDLED_MSGPACK=OFF \
	-DUSE_BUNDLED_LUAJIT=OFF \
	-DUSE_BUNDLED_LUAROCKS=OFF \
	-DUSE_BUNDLED_LUV=OFF \
	../third-party
%{__make}

cd ../build
%cmake \
	-DLUA_PRG=/usr/bin/lua5.1 \
	-DENABLE_JEMALLOC=ON \
	-DLUAJIT_USE_BUNDLED=OFF \
	-DLIBUV_USE_BUNDLED=OFF \
	-DMSGPACK_USE_BUNDLED=OFF \
	-DUNIBILIUM_USE_BUNDLED=OFF \
	-DLIBTERMKEY_USE_BUNDLED=OFF \
	-DLIBVTERM_USE_BUNDLED=OFF \
	-DJEMALLOC_USE_BUNDLED=OFF \
	..

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT{/etc/xdg/nvim,%{_desktopdir},%{_iconsdir}/hicolor/scalable/apps}
touch $RPM_BUILD_ROOT/etc/xdg/nvim/init.vim
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{_desktopdir}/neovim.desktop
cp -p %{SOURCE2} $RPM_BUILD_ROOT%{_iconsdir}/hicolor/scalable/apps/neovim.svg

%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/cs.cp1250
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/ja.euc-jp
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/ko.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/no
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/pl.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/sk.cp1250
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/zh_CN.UTF-8
%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/zh_TW.UTF-8

%find_lang nvim

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_desktop_database
%update_icon_cache hicolor
%banner -e -o %{name} << 'EOF'

The Neovim executable is called 'nvim'. To use your existing Vim
configuration:
    ln -s ~/.vim ~/.config/nvim
    ln -s ~/.vimrc ~/.config/nvim/init.vim
See ':help nvim' for more information on Neovim.

If you want support for Python plugins such as YouCompleteMe, you need
to install a Python module in addition to Neovim itself.

See ':help provider-python' or this page for more information:
    http://neovim.io/doc/user/provider.html

If you have any questions, have a look at:
    https://github.com/neovim/neovim/wiki/FAQ.
EOF

%postun
%update_desktop_database
%update_icon_cache hicolor

%files -f nvim.lang
%defattr(644,root,root,755)
%doc BACKERS.md CONTRIBUTING.md LICENSE README.md
%dir /etc/xdg/nvim
%config(noreplace) %verify(not md5 mtime size) /etc/xdg/nvim/init.vim
%attr(755,root,root) %{_bindir}/nvim
%{_datadir}/nvim
%{_desktopdir}/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.svg
%{_mandir}/man1/nvim.1*
%changelog
* Sat Aug 12 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/neovim.git;a=log;h=master

* Thu Aug 10 2017 Elan Ruusamäe <glen@pld-linux.org> f7b621b
- up to 0.2.0

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> cebcf7f
- add link for vim/nvim bindings incompat

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> f4df6d0
- up to 0.1.7

* Fri Jan 20 2017 Elan Ruusamäe <glen@delfi.ee> 4350fc3
- up to 0.1.6

* Tue Oct 11 2016 Elan Ruusamäe <glen@delfi.ee> 82b424f
- rebuild for x32
- release 2 (by relup.sh)

* Mon Sep 26 2016 Elan Ruusamäe <glen@delfi.ee> 9277ef3
- annoyed by alt+<x> hotkeys not working

* Sun Sep 18 2016 Elan Ruusamäe <glen@delfi.ee> 3f05c04
- suggest ruby-neovim

* Sun Sep 18 2016 Elan Ruusamäe <glen@delfi.ee> 3fb7b0d
- package nvimi/init.vim - place for per site global customizations

* Sun Sep 18 2016 Elan Ruusamäe <glen@delfi.ee> 2d2f06e
- use lua51 instead of luajit, to build also for x32

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> 9502eba
- works; rel 1

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> 8c8b1ac
- cleanup/update BR

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> 48fc328
- build with system deps

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> e723345
- cleanup __DATE__/__TIME__ replacement

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> 4624002
- drop unsupported locales

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> a2169a2
- disable _FORTIFY_SOURCE=2

* Sat Sep 17 2016 Elan Ruusamäe <glen@delfi.ee> 7d69921
- build with most of the system libs

* Fri Sep 16 2016 Elan Ruusamäe <glen@delfi.ee> b086dcf
- add post install banner

* Wed Sep 14 2016 Elan Ruusamäe <glen@delfi.ee> ccead67
- builds with bundled deps

* Tue Sep 13 2016 Elan Ruusamäe <glen@delfi.ee> 0a9d0af
- new, version 0.1.5

